==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/HeaderSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderSeparatorDescription } from "./HeaderSeparatorDescription";
/**
 * @hidden
 */
export let HeaderSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderSeparatorDescriptionMetadata.a == null) {
                HeaderSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderSeparatorDescriptionMetadata.c(HeaderSeparatorDescriptionMetadata.a);
            }
            if (a.k(HeaderSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(HeaderSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            HeaderSeparatorDescriptionMetadata.b(a);
            a.ad("HeaderSeparator", () => new HeaderSeparatorDescription());
            a.ac("HeaderSeparator", HeaderSeparatorDescriptionMetadata.a);
        }
    }
    HeaderSeparatorDescriptionMetadata.$t = markType(HeaderSeparatorDescriptionMetadata, 'HeaderSeparatorDescriptionMetadata');
    HeaderSeparatorDescriptionMetadata.a = null;
    return HeaderSeparatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/HeaderSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderSeparatorDescription } from "./HeaderSeparatorDescription";
/**
 * @hidden
 */
export let HeaderSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderSeparatorDescriptionMetadata.a == null) {
                HeaderSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderSeparatorDescriptionMetadata.c(HeaderSeparatorDescriptionMetadata.a);
            }
            if (a.k(HeaderSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(HeaderSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            HeaderSeparatorDescriptionMetadata.b(a);
            a.ae("HeaderSeparator", () => new HeaderSeparatorDescription());
            a.ad("HeaderSeparator", HeaderSeparatorDescriptionMetadata.a);
        }
    }
    HeaderSeparatorDescriptionMetadata.$t = markType(HeaderSeparatorDescriptionMetadata, 'HeaderSeparatorDescriptionMetadata');
    HeaderSeparatorDescriptionMetadata.a = null;
    return HeaderSeparatorDescriptionMetadata;
})();
